The ashnazg package is my first foray into pypi package maintenance.
(And my first project in python since the invention of python3, so PRs and comments to help me improve my idiomatic pythoness are appreciated.)

The sub module fairy is a tool for reading and writing FAIR data sets.
